"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConstructableGPIOInterface = exports.GPIOInterface = exports.GPIOState = void 0;
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const InterfaceType = 'gpio';
var GPIOState;
(function (GPIOState) {
    GPIOState["Unknown"] = "unknown";
    GPIOState["Error"] = "error";
    GPIOState["StrongLow"] = "strongL";
    GPIOState["StrongHigh"] = "strongH";
    GPIOState["HighZ"] = "highZ";
    GPIOState["WeakLow"] = "weakL";
    GPIOState["WeakHigh"] = "weakH";
})(GPIOState || (exports.GPIOState = GPIOState = {}));
class GPIOInterface extends tiny_typed_emitter_1.TypedEmitter {
    constructor(configuration) {
        super();
        this.interfaceType = InterfaceType;
        this.signalState = GPIOState.Unknown;
        this.driverStates = new Map();
        this.driverState = GPIOState.Unknown;
        this.configuration = configuration;
        this.signal = configuration.signals.gpio;
        const dir = configuration.direction ?? 'inout';
        if (dir != 'in') {
            this.driver = configuration.driver ?? 'default';
        }
    }
    // changes the driver of this device
    changeDriver(state) {
        if (this.driver && this.driverState !== state) {
            this.driverState = state;
            const data = { driver: this.driver, state: state };
            this.emit('upstreamData', data);
            this.downstreamData(data); // use the same mechanismn as any other driver data from external devices
        }
    }
    retransmit() {
        if (this.driver) {
            const data = {
                driver: this.driver,
                state: this.driverState,
            };
            this.emit('upstreamData', data);
        }
    }
    downstreamData(data) {
        this.driverStates.set(data.driver, data.state);
        this.evaluateSignalState();
    }
    evaluateSignalState() {
        const states = new Set();
        for (const [_driver, state] of this.driverStates) {
            states.add(state);
        }
        let newState = GPIOState.HighZ;
        if (states.has(GPIOState.Error)) {
            newState = GPIOState.Error;
        }
        else if (states.has(GPIOState.StrongHigh) && states.has(GPIOState.StrongLow)) {
            newState = GPIOState.Error;
        }
        else if (states.has(GPIOState.Unknown)) {
            newState = GPIOState.Unknown;
        }
        else if (states.has(GPIOState.StrongHigh)) {
            newState = GPIOState.StrongHigh;
        }
        else if (states.has(GPIOState.StrongLow)) {
            newState = GPIOState.StrongLow;
        }
        else if (states.has(GPIOState.WeakHigh) && states.has(GPIOState.WeakLow)) {
            newState = GPIOState.Unknown;
        }
        else if (states.has(GPIOState.WeakHigh)) {
            newState = GPIOState.WeakHigh;
        }
        else if (states.has(GPIOState.WeakLow)) {
            newState = GPIOState.WeakLow;
        }
        if (newState !== this.signalState) {
            const event = { oldState: this.signalState, state: newState };
            this.signalState = newState;
            this.emit('signalChange', event);
        }
    }
}
exports.GPIOInterface = GPIOInterface;
class ConstructableGPIOInterface {
    constructor(gpios) {
        this.interfaceType = InterfaceType;
        this.gpios = gpios;
    }
    getDescription() {
        return {
            availableSignals: { gpio: this.gpios },
        };
    }
    create(configuration) {
        return new GPIOInterface(configuration);
    }
}
exports.ConstructableGPIOInterface = ConstructableGPIOInterface;
//# sourceMappingURL=connectionInterface.js.map