import { TypedEmitter } from 'tiny-typed-emitter';
import { ConnectionInterfaceEvents } from '../connectionInterface';
import { ConnectionInterface, ConnectionInterfaceConfiguration, ConnectionInterfaceDescription, ConstructableConnectionInterface } from '../connectionInterface';
type InterfaceType = 'twi' | 'twiSlave' | 'twiMaster';
declare const InterfaceType: InterfaceType;
export interface TWIConfiguration extends ConnectionInterfaceConfiguration {
    signals: {
        scl: string;
        sda: string;
    };
    frequency: number;
    isMaster: boolean;
    address: number;
}
export type ReceiveByteEvent = {
    byte: number;
};
export interface TWISlaveInterfaceEvents extends ConnectionInterfaceEvents {
    receiveByte(event: ReceiveByteEvent): void;
}
export interface TWIMasterInterfaceEvents extends ConnectionInterfaceEvents {
    prepareByte(event: ReceiveByteEvent): void;
}
export declare class TWIMasterInterface extends TypedEmitter<TWIMasterInterfaceEvents> implements ConnectionInterface {
    interfaceType: InterfaceType;
    readonly configuration: TWIConfiguration;
    constructor(configuration: TWIConfiguration);
    retransmit(): void;
    downstreamData(data: unknown): void;
    sendByte(byte: number): void;
    sendAddress(address: number, read: boolean): void;
}
export declare class TWISlaveInterface extends TypedEmitter<TWISlaveInterfaceEvents> implements ConnectionInterface {
    interfaceType: InterfaceType;
    readonly configuration: TWIConfiguration;
    constructor(configuration: TWIConfiguration);
    retransmit(): void;
    downstreamData(data: unknown): void;
    prepareByte(byte: number): void;
}
export declare class ConstructableTWIInterface implements ConstructableConnectionInterface {
    interfaceType: InterfaceType;
    private signals;
    constructor(signals: string[]);
    getDescription(): ConnectionInterfaceDescription;
    create(configuration: TWIConfiguration): TWIMasterInterface | TWISlaveInterface;
}
export {};
//# sourceMappingURL=connectionInterface.d.ts.map